@@ -1,5 +1,5 @@
-from binance.streams import BinanceSocketManager
-from binance.client import AsyncClient
+from binance import BinanceSocketManager
+from binance import AsyncClient
 import pytest
 
 
@@ -7,9 +7,9 @@ import pytest
 async def test_socket_stopped_on_aexit():
     client = AsyncClient()
     bm = BinanceSocketManager(client)
-    ts1 = bm.trade_socket('BNBBTC')
+    ts1 = bm.trade_socket("BNBBTC")
     async with ts1:
         pass
-    ts2 = bm.trade_socket('BNBBTC')
+    ts2 = bm.trade_socket("BNBBTC")
     assert ts2 is not ts1, "socket should be removed from _conn on exit"
     await client.close_connection()
